# krk

<!-- CI status -->
[![ci](https://github.com/krakakai/krk/workflows/ci/badge.svg)](https://github.com/krakakai/krk/actions?query=workflow=ci)
[![pypi](https://img.shields.io/pypi/v/krk)](https://pypi.org/project/krk/)
[![last commit](https://badgen.net/github/last-commit/krakakai/krk)](https://GitHub.com/krakakai/krk/commit/)
[![license](https://img.shields.io/github/license/krakakai/krk.svg)](https://github.com/krakakai/krk/blob/master/LICENSE)


<!-- short description -->
A command-line utiltiy for all krakakai projects.


## Aims

<!-- more detailed description -->

## Documentation

Find the documentation at [the github.io page](https://krakakai.github.io/libraries/krk/krk.html)

## Build instructions

<!-- instructions to get the simplest example working -->

## Contributing

<!-- rules/suggestions -->
